==> Banners-2.3.7.tar.gz: Banners/lang/ext/sk_SK.php <==
<?php
$lang['help_param_action'] = 'Specify the behaviour of the module.  Possible values are &quot;default&quot; and &quot;list&quot;.  The default action is used for displaying a single banner according to specified criterium.  The list action is used to display all of the banners of a specified category or category id';
$lang['help_param_category'] = 'In the default action, this parameter is used to specify the name of the category from which a single banner will be displayed.  In the list action this parameter is required to specify the name of the category from which all banners will be displayed';
$lang['help_param_mode'] = 'This parameter is only used in the default action, it specifies the way in which banners are selected from the specified category.  The only value is &quot;sequential&quot; which indicates that the module should choose the next non expired banner with the least amount of impressions.  Not specifying this parameter will result in a random banner being selected';
$lang['help_param_name'] = 'Parameter použivan&yacute; pri action=&quot;default&quot;. Konkretizuje n&aacute;zov bannera pre zobrazenie.  Pokiaľ je banner nakt&iacute;vny, nezobraz&iacute; sa.';
$lang['bannerlist_template'] = '&Scaron;al&oacute;na v&yacute;pisu bannerov';
$lang['info_bannerlist_template'] = 'Použit&yacute; pri akcii v&yacute;pisu zoznamu (action=list), zobrazuje v&scaron;etky bannery v danej kateg&oacute;rii ';
$lang['none'] = 'Žiadny';
$lang['error_invalid_dates'] = 'Chybn&yacute; form&aacute;t d&aacute;tumu';
$lang['editbanner'] = 'Upraviť banner';
$lang['start_date'] = 'Začiatok';
$lang['atttext'] = 'v';
$lang['template'] = '&Scaron;abl&oacute;na';
$lang['default_template'] = 'Prednastaven&aacute; &scaron;abl&oacute;na kateg&oacute;rii';
$lang['reset_template'] = 'Nastaviť obsah prednastavenej &scaron;abl&oacute;ny';
$lang['error_banners'] = 'Žiadne bannery';
$lang['error_bannerexists'] = 'Banner s t&yacute;mto n&aacute;zvom už existuje';
$lang['accessdenied'] = 'Pr&iacute;stup zamietnut&yacute;, skontrolujte va&scaron;e pr&iacute;stpupov&eacute; pr&aacute;va';
$lang['addbanner'] = 'Pridať banner';
$lang['addcategory'] = 'Pridať kateg&oacute;riu';
$lang['areyousure'] = 'Ste si ist&yacute;?';
$lang['banners'] = 'Bannery';
$lang['cancel'] = 'Zru&scaron;iť';
$lang['categories'] = 'Kateg&oacute;rie';
$lang['category'] = 'Kateg&oacute;ria';
$lang['created'] = 'Vytvoren&eacute;';
$lang['date'] = 'D&aacute;tum';
$lang['delete'] = 'Odstr&aacute;niť';
$lang['description'] = 'Popis';
$lang['edit'] = 'Uprav';
$lang['editcategory'] = 'Uprav kateg&oacute;riu';
$lang['error'] = 'Chyba!';
$lang['error_banerexists'] = 'Banner s t&yacute;mto n&aacute;zvom už existuje';
$lang['error_categorynotempty'] = 'Chyba: Kateg&oacute;ria nem&ocirc;že byť pr&aacute;zdna!';
$lang['error_dberror'] = 'Chyba: V datab&aacute;ze!';
$lang['error_emptybannername'] = 'Chyba: N&aacute;zov bannera nem&ocirc;že byť pr&aacute;zdny!';
$lang['error_emptycategory'] = 'Chyba: Kateg&oacute;ria nem&ocirc;že byť pr&aacute;znda!';
$lang['error_insufficientparams'] = 'Chyba: Nedostatok vstupn&yacute;ch paramentrov';
$lang['error_nocategories'] = 'Chyba: Neboli n&aacute;jden&eacute; žiadne kateg&oacute;rie';
$lang['error_noresults'] = 'Nezodpoved&aacute; žiadny banner';
$lang['error_textorimage'] = 'Zadajte URL a obr&aacute;zok, alebo text, nie oboje';
$lang['expires'] = 'Expir&aacute;cia';
$lang['friendlyname'] = 'Spr&aacute;va bannerov';
$lang['height'] = 'V&yacute;&scaron;ka';
$lang['hits'] = 'Kliknut&iacute;';
$lang['href_text'] = 'Textov&yacute; odkaz';
$lang['id'] = 'Id';
$lang['image'] = 'Obr&aacute;zok';
$lang['image_text'] = 'ALT popis k obr&aacute;zku';
$lang['impressions'] = 'Impresie';
$lang['info_href_text'] = 'Text v odkaze.';
$lang['info_image'] = 'Relat&iacute;vna cesta k uploads adres&aacute;ru';
$lang['info_image_text'] = 'ALT text pre obr&aacute;zok';
$lang['info_max_hits'] = 'Použite 0 pre neobmedzen&yacute; počet klikov';
$lang['info_max_impressions'] = 'Použite 0 pre neobmedzen&yacute; počet zobrazen&iacute;';
$lang['installed'] = 'Modul verzia %s nain&scaron;talova&yacute;.';
$lang['ipaddress'] = 'IP adresa';
$lang['max_hits'] = 'Maximum kliknut&iacute;';
$lang['max_impressions'] = 'Maximum impresii';
$lang['name'] = 'N&aacute;zov';
$lang['never'] = 'Nikdy';
$lang['postinstall'] = 'Post Install Message, e.g., Be sure to set &quot;Manage Banners&quot; permissions to use this module!';
$lang['postuninstall'] = 'Banners module uninstalled, and all database tables removed.  Sorry to see you leave.&quot;';
$lang['preferences'] = 'Nastavenia';
$lang['prefsupdated'] = 'Nastavenia modulu aktualizovan&eacute;';
$lang['prompt_categorydesc'] = 'Popis kateg&oacute;rie';
$lang['prompt_categoryname'] = 'N&aacute;zov kateg&oacute;rie';
$lang['prompt_imageheight'] = 'V&yacute;&scaron;ka obr&aacute;zku';
$lang['prompt_imagewidth'] = 'Veľkosť obr&aacute;zu';
$lang['prompt_subnet_exclusions'] = 'Vyradiť tieto subnets zo &scaron;tatist&iacute;k';
$lang['prompt_upload_category'] = 'Kateg&oacute;ria (Uploads modul)';
$lang['prompt_upload_file'] = 'Obr&aacute;zok (Uploads modul)';
$lang['selectcategory'] = 'Vyberte kateg&oacute;riu';
$lang['submit'] = 'Odoslať';
$lang['text'] = 'Text';
$lang['title_mod_admin'] = 'Administr&aacute;cia modulu';
$lang['title_mod_prefs'] = 'Nastavenia modulu';
$lang['uninstalled'] = 'Modul odin&scaron;talovan&yacute;';
$lang['upgraded'] = 'Modul aktualizovan&yacute; na verziu %s.';
$lang['url'] = 'Url';
$lang['width'] = 'Dĺžka';
$lang['title_admin_panel'] = 'Spr&aacute;va bannerov';
$lang['moddescription'] = 'Modul umožnuje spr&aacute;vu bannerov';
$lang['welcome_text'] = '<p>Vitaj v administr&aacute;cia pre spr&aacute;vu bannerov.</p>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This banner manages numerous categories of banners, tracks hits, impressions, and expiry dates, and randomly selects from all available and valid banners for one to display</p>
<h3>How Do I Use It</h3>
<p>To use this module, place the module code in a page or template using the smarty tag {Banners category=&quot;categoryname&quot;}</p> 
<p>You must also upload banners to a suitable directory within the uploads directory and must use the admin panel interface to add banners to the database.</p
<h3>Parameters</h3>
<ul>
<li><em>(REQUIRED)</em> category=&quot;category&quot; = randomly select from all available in this category</li>
<li><em>(optional)</em> name=&quot;name&quot; = select only the banner with this name</li>
<li><em>(optional)</em> mode=&quot;sequential&quot; = Instead of randomly selecting a valid banner, select the one with the least impressions.</li>
</ul>
<h4>Hint</h4>
<p>The uploads module and the banners module work well together.  You can create a &quot;banners&quot; category in the uploads module, and upload your banner images there, then specify &quot;banners/<filename>&quot; when adding a banner in the banners module.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy&#039;s
module homepage at <a href="http://techcom.dyndns.org">techcom.dyndns.org</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org"><calguy1000@cmsmadesimple.org></a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['qca'] = 'P0-1608926040-1271144175783';
$lang['utma'] = '156861353.786385904.1271157997.1284636351.1284708974.100';
$lang['utmz'] = '156861353.1284117455.97.92.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>

==> Banners-2.6.tar.gz: Banners/lang/ext/sk_SK.php <==
<?php
$lang['statreport_linesperpage'] = 'Lines per page on the statistics report';
$lang['banner'] = 'Banner Advertisement';
$lang['of'] = 'z';
$lang['page'] = 'Strana';
$lang['generated'] = 'Vytvoren&eacute;';
$lang['generated_by'] = 'Vytvoren&eacute;';
$lang['desc_stats_report'] = 'A report illustrating the number of impressions and click-through hits from the Banners module';
$lang['title_stats_report'] = 'Banner Statistics Report';
$lang['view_statistics'] = 'Pozrieť &scaron;tatistiky';
$lang['msg_new_window'] = 'Otvor&iacute; sa v novom okne';
$lang['statreport_template'] = 'Statistics Report Template';
$lang['your_ad_here'] = 'Your Advertisement could be here';
$lang['prompt_dflt_image'] = 'Default Image';
$lang['prompt_dflt_url'] = 'Default URL';
$lang['info_dflt_image'] = 'Specify an image name (relative to the uploads directory) of an image to use when no banners are valid to be displayed';
$lang['prompt_hidefrombots'] = 'Exclude robots from impression and click counting';
$lang['help_param_action'] = 'Specify the behaviour of the module.  Possible values are &quot;default&quot; and &quot;list&quot;.  The default action is used for displaying a single banner according to specified criterium.  The list action is used to display all of the banners of a specified category or category id';
$lang['help_param_category'] = 'In the default action, this parameter is used to specify the name of the category from which a single banner will be displayed.  In the list action this parameter is required to specify the name of the category from which all banners will be displayed';
$lang['help_param_mode'] = 'This parameter is only used in the default action, it specifies the way in which banners are selected from the specified category.  The only value is &quot;sequential&quot; which indicates that the module should choose the next non expired banner with the least amount of impressions.  Not specifying this parameter will result in a random banner being selected';
$lang['help_param_name'] = 'Parameter použivan&yacute; pri action=&quot;default&quot;. Konkretizuje n&aacute;zov bannera pre zobrazenie.  Pokiaľ je banner nakt&iacute;vny, nezobraz&iacute; sa.';
$lang['bannerlist_template'] = '&Scaron;al&oacute;na v&yacute;pisu bannerov';
$lang['info_bannerlist_template'] = 'Použit&yacute; pri akcii v&yacute;pisu zoznamu (action=list), zobrazuje v&scaron;etky bannery v danej kateg&oacute;rii ';
$lang['none'] = 'Žiadny';
$lang['error_invalid_dates'] = 'Chybn&yacute; form&aacute;t d&aacute;tumu';
$lang['editbanner'] = 'Upraviť banner';
$lang['start_date'] = 'Začiatok';
$lang['atttext'] = 'v';
$lang['template'] = '&Scaron;abl&oacute;na';
$lang['default_template'] = 'Prednastaven&aacute; &scaron;abl&oacute;na kateg&oacute;rii';
$lang['reset_template'] = 'Nastaviť obsah prednastavenej &scaron;abl&oacute;ny';
$lang['error_banners'] = 'Žiadne bannery';
$lang['error_bannerexists'] = 'Banner s t&yacute;mto n&aacute;zvom už existuje';
$lang['accessdenied'] = 'Pr&iacute;stup zamietnut&yacute;, skontrolujte va&scaron;e pr&iacute;stpupov&eacute; pr&aacute;va';
$lang['addbanner'] = 'Pridať banner';
$lang['addcategory'] = 'Pridať kateg&oacute;riu';
$lang['areyousure'] = 'Ste si ist&yacute;?';
$lang['banners'] = 'Bannery';
$lang['cancel'] = 'Zru&scaron;iť';
$lang['categories'] = 'Kateg&oacute;rie';
$lang['category'] = 'Kateg&oacute;ria';
$lang['created'] = 'Vytvoren&eacute;';
$lang['date'] = 'D&aacute;tum';
$lang['delete'] = 'Odstr&aacute;niť';
$lang['description'] = 'Popis';
$lang['edit'] = 'Uprav';
$lang['editcategory'] = 'Uprav kateg&oacute;riu';
$lang['error'] = 'Chyba!';
$lang['error_banerexists'] = 'Banner s t&yacute;mto n&aacute;zvom už existuje';
$lang['error_categorynotempty'] = 'Chyba: Kateg&oacute;ria nem&ocirc;že byť pr&aacute;zdna!';
$lang['error_dberror'] = 'Chyba: V datab&aacute;ze!';
$lang['error_emptybannername'] = 'Chyba: N&aacute;zov bannera nem&ocirc;že byť pr&aacute;zdny!';
$lang['error_emptycategory'] = 'Chyba: Kateg&oacute;ria nem&ocirc;že byť pr&aacute;znda!';
$lang['error_insufficientparams'] = 'Chyba: Nedostatok vstupn&yacute;ch paramentrov';
$lang['error_nocategories'] = 'Chyba: Neboli n&aacute;jden&eacute; žiadne kateg&oacute;rie';
$lang['error_noresults'] = 'Nezodpoved&aacute; žiadny banner';
$lang['error_textorimage'] = 'Zadajte URL a obr&aacute;zok, alebo text, nie oboje';
$lang['expires'] = 'Expir&aacute;cia';
$lang['friendlyname'] = 'Spr&aacute;va bannerov';
$lang['height'] = 'V&yacute;&scaron;ka';
$lang['hits'] = 'Kliknut&iacute;';
$lang['href_text'] = 'Textov&yacute; odkaz';
$lang['id'] = 'Id';
$lang['image'] = 'Obr&aacute;zok';
$lang['image_text'] = 'ALT popis k obr&aacute;zku';
$lang['impressions'] = 'Impresie';
$lang['info_href_text'] = 'Text v odkaze.';
$lang['info_image'] = 'Relat&iacute;vna cesta k uploads adres&aacute;ru';
$lang['info_image_text'] = 'ALT text pre obr&aacute;zok';
$lang['info_max_hits'] = 'Použite 0 pre neobmedzen&yacute; počet klikov';
$lang['info_max_impressions'] = 'Použite 0 pre neobmedzen&yacute; počet zobrazen&iacute;';
$lang['installed'] = 'Modul verzia %s nain&scaron;talova&yacute;.';
$lang['ipaddress'] = 'IP adresa';
$lang['max_hits'] = 'Maximum kliknut&iacute;';
$lang['max_impressions'] = 'Maximum impresii';
$lang['name'] = 'N&aacute;zov';
$lang['never'] = 'Nikdy';
$lang['postinstall'] = 'Post Install Message, e.g., Be sure to set &quot;Manage Banners&quot; permissions to use this module!';
$lang['postuninstall'] = 'Banners module uninstalled, and all database tables removed.  Sorry to see you leave.&quot;';
$lang['preferences'] = 'Nastavenia';
$lang['prefsupdated'] = 'Nastavenia modulu aktualizovan&eacute;';
$lang['prompt_categorydesc'] = 'Popis kateg&oacute;rie';
$lang['prompt_categoryname'] = 'N&aacute;zov kateg&oacute;rie';
$lang['prompt_imageheight'] = 'V&yacute;&scaron;ka obr&aacute;zku';
$lang['prompt_imagewidth'] = 'Veľkosť obr&aacute;zu';
$lang['prompt_subnet_exclusions'] = 'Vyradiť tieto subnets zo &scaron;tatist&iacute;k';
$lang['prompt_upload_category'] = 'Kateg&oacute;ria (Uploads modul)';
$lang['prompt_upload_file'] = 'Obr&aacute;zok (Uploads modul)';
$lang['selectcategory'] = 'Vyberte kateg&oacute;riu';
$lang['submit'] = 'Odoslať';
$lang['text'] = 'Text';
$lang['title_mod_admin'] = 'Administr&aacute;cia modulu';
$lang['title_mod_prefs'] = 'Nastavenia modulu';
$lang['uninstalled'] = 'Modul odin&scaron;talovan&yacute;';
$lang['upgraded'] = 'Modul aktualizovan&yacute; na verziu %s.';
$lang['url'] = 'URL';
$lang['width'] = 'Dĺžka';
$lang['title_admin_panel'] = 'Spr&aacute;va bannerov';
$lang['moddescription'] = 'Modul umožnuje spr&aacute;vu bannerov';
$lang['welcome_text'] = '<p>Vitaj v administr&aacute;cia pre spr&aacute;vu bannerov.</p>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This banner manages numerous categories of banners, tracks hits, impressions, and expiry dates, and randomly selects from all available and valid banners for one to display</p>
<h3>How Do I Use It</h3>
<p>To use this module, place the module code in a page or template using the smarty tag {Banners category=&quot;categoryname&quot;}</p> 
<p>You must also upload banners to a suitable directory within the uploads directory and must use the admin panel interface to add banners to the database.</p
<h3>Parameters</h3>
<ul>
<li><em>(REQUIRED)</em> category=&quot;category&quot; = randomly select from all available in this category</li>
<li><em>(optional)</em> name=&quot;name&quot; = select only the banner with this name</li>
<li><em>(optional)</em> mode=&quot;sequential&quot; = Instead of randomly selecting a valid banner, select the one with the least impressions.</li>
</ul>
<h4>Hint</h4>
<p>The uploads module and the banners module work well together.  You can create a &quot;banners&quot; category in the uploads module, and upload your banner images there, then specify &quot;banners/<filename>&quot; when adding a banner in the banners module.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy&#039;s
module homepage at <a href="http://techcom.dyndns.org">techcom.dyndns.org</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org"><calguy1000@cmsmadesimple.org></a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
?>
